@@ -4,9 +4,6 @@ if [[ `uname` == "Linux" ]] && [[ "${GFORTRAN}" != "gfortran" ]]; then
     ln -s ${GFORTRAN} ${BUILD_PREFIX}/bin/gfortran
 fi
 
-EXTRA_FFLAGS=-ffast-math make camb
+rm -rf forutils
 
-make clean
-
-cd pycamb
 python setup.py build
